/*
 * Licensed Materials - Property of IBM Corp.
 * IBM UrbanCode Deploy
 * (c) Copyright IBM Corporation 2016, 2017. All Rights Reserved.
 *
 * U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by
 * GSA ADP Schedule Contract with IBM Corp.
 */
import com.urbancode.air.AirPluginTool
import com.urbancode.air.plugin.wldeploy.WebLogicStatusHelper

final def workDir = new File('.').canonicalFile
AirPluginTool apTool = new AirPluginTool(this.args[0], this.args[1])
def props = apTool.getStepProperties(System.getenv("UCD_SECRET_VAR"))

final def inputPropsFile = new File(args[0])
final def inputPropsStream = null
try {
    inputPropsStream = new FileInputStream(inputPropsFile)
    props.load(inputPropsStream)
}
catch (IOException e) {
    throw new RuntimeException(e)
}
final def jmxUrl = props['jmxUrl']
def user = props['user']
def pass = props['password']
final def configFile = props['configFile']
final def keyFile = props['keyFile']
def targets = props['targets']
def badStatuses = []

targets = targets.split(',')

try {
    WebLogicStatusHelper helper = new WebLogicStatusHelper()
    if (configFile) {
        user = helper.getUser(configFile, keyFile)
        pass = helper.getPass(configFile, keyFile)
    }
    helper.initConn(jmxUrl, user, pass)
    targets.each { target ->
        System.out.println("Checking Target ${target}")
        def status = helper.getManagedServerStatus(target)
        if (status instanceof List) {
            status.each { serverStatusPair ->
                println serverStatusPair
                if (serverStatusPair[1] != "RUNNING") {
                    badStatuses << [serverStatusPair[0], serverStatusPair[1]]
                }
            }
        }
        else {
            println status
            if (status != "RUNNING") {
                badStatuses << [target, status]
            }
        }
    }
    helper.closeConn()

    if (!badStatuses.isEmpty()) {
        badStatuses.each { status ->
            System.out.println(status[0] + " is not in running state : " + status[1])
        }
        System.exit(1)
    }
    System.exit(0)
}
catch (Exception e) {
    e.printStackTrace()
    throw e
}
